pub struct ConGraph { /* private fields */ }Expand description
A connectivity only hypergraph object. Essentially a wrapper
around HGraph with simpler add nodes/edges and simpler
serialization to and from disk.
Implementations
Sourceimpl ConGraph
impl ConGraph
pub fn new() -> ConGraph
Sourcepub fn add_nodes(&mut self, num_nodes: usize) -> Vec<u32>
pub fn add_nodes(&mut self, num_nodes: usize) -> Vec<u32>
Adds num_nodes nodes to the graph, returning a vector containing
the nodes created. panics if it runs out of nodes to allocate.
Sourcepub fn remove_node(&mut self, node: u32)
pub fn remove_node(&mut self, node: u32)
Removes the node and any empty edges if the provided node is the last on in the edge. Singleton edges are allowed. For example, if you remove 2 from the edge {1, 2} the graph will retain the edge {1} so that way further nodes can be added back to the edge. If 1 is then removed the empty edge will be deleted.
Sourcepub fn remove_nodes(&mut self, nodes: Vec<u32>)
pub fn remove_nodes(&mut self, nodes: Vec<u32>)
Removes a collection of nodes and any resulting empty edges.
Sourcepub fn add_edge(&mut self, nodes: impl AsRef<[u32]>) -> u64
pub fn add_edge(&mut self, nodes: impl AsRef<[u32]>) -> u64
Creates an undirected edge among the given nodes with duplicate nodes removed. Duplicate edges are not allowed.
panics
- If not all nodes are present in the hypergraph
- If you run out of possible id’s usable with the
EdgeIDstorage type
pub fn remove_edge(&mut self, edge_id: u64)
Sourcepub fn cut(&self, cut_nodes: impl AsRef<[u32]>) -> usize
pub fn cut(&self, cut_nodes: impl AsRef<[u32]>) -> usize
Computes the number of edges that have one vertex in the
provided cut_nodes and one in the remaining set. For example,
an edge with only support on the cut_nodes would not count. Neither
would an edge without any nodes in cut_nodes.
The type ToSet is any collection that can be converted to a sparse
set representation.
Sourcepub fn to_disk(&self, path: &Path)
pub fn to_disk(&self, path: &Path)
Saves the disk in the same format as the graph is displayed. panics
if the path is incorrect or the file cannot be written.
pub fn from_file(path: &Path) -> Option<Self>